@@ -23,7 +23,7 @@
 from __future__ import absolute_import
 
 import sys
-import gobject
+from . import _gobject
 
 from ._gi import \
     InterfaceInfo, \
@@ -40,8 +40,8 @@ if sys.version_info > (3, 0):
 
 def Function(info):
 
-    def function(*args):
-        return info.invoke(*args)
+    def function(*args, **kwargs):
+        return info.invoke(*args, **kwargs)
     function.__info__ = info
     function.__name__ = info.get_name()
     function.__module__ = info.get_namespace()
@@ -51,8 +51,8 @@ def Function(info):
 
 def NativeVFunc(info, cls):
 
-    def native_vfunc(*args):
-        return info.invoke(*args, gtype=cls.__gtype__)
+    def native_vfunc(*args, **kwargs):
+        return info.invoke(cls.__gtype__, *args, **kwargs)
     native_vfunc.__info__ = info
     native_vfunc.__name__ = info.get_name()
     native_vfunc.__module__ = info.get_namespace()
@@ -61,11 +61,11 @@ def NativeVFunc(info, cls):
 
 def Constructor(info):
 
-    def constructor(cls, *args):
+    def constructor(cls, *args, **kwargs):
         cls_name = info.get_container().get_name()
         if cls.__name__ != cls_name:
             raise TypeError('%s constructor cannot be used to create instances of a subclass' % cls_name)
-        return info.invoke(cls, *args)
+        return info.invoke(cls, *args, **kwargs)
 
     constructor.__info__ = info
     constructor.__name__ = info.get_name()
@@ -172,8 +172,8 @@ def find_vfunc_info_in_interface(bases, vfunc_name):
         # This can be seen in IntrospectionModule.__getattr__() in module.py.
         # We do not need to search regular classes here, only wrapped interfaces.
         # We also skip GInterface, because it is not wrapped and has no __info__ attr.
-        if base is gobject.GInterface or\
-                not issubclass(base, gobject.GInterface) or\
+        if base is _gobject.GInterface or\
+                not issubclass(base, _gobject.GInterface) or\
                 not isinstance(base.__info__, InterfaceInfo):
             continue
 
@@ -203,7 +203,7 @@ def find_vfunc_conflict_in_bases(vfunc, bases):
             return aklass
     return None
 
-class GObjectMeta(gobject.GObjectMeta, MetaClassHelper):
+class GObjectMeta(_gobject.GObjectMeta, MetaClassHelper):
 
     def __init__(cls, name, bases, dict_):
         super(GObjectMeta, cls).__init__(name, bases, dict_)
@@ -244,13 +244,13 @@ def mro(C):
     bases_of_subclasses = [[C]]
 
     if C.__bases__:
-        bases_of_subclasses += map(mro, C.__bases__) + [list(C.__bases__)]
+        bases_of_subclasses += list(map(mro, C.__bases__)) + [list(C.__bases__)]
 
     while bases_of_subclasses:
         for subclass_bases in bases_of_subclasses:
             candidate = subclass_bases[0]
             not_head = [s for s in bases_of_subclasses if candidate in s[1:]]
-            if not_head and gobject.GInterface not in candidate.__bases__:
+            if not_head and _gobject.GInterface not in candidate.__bases__:
                 candidate = None # conflict, reject candidate
             else:
                 break
@@ -277,7 +277,7 @@ class StructMeta(type, MetaClassHelper):
 
         # Avoid touching anything else than the base class.
         g_type = cls.__info__.get_g_type()
-        if g_type != gobject.TYPE_INVALID and g_type.pytype is not None:
+        if g_type != _gobject.TYPE_INVALID and g_type.pytype is not None:
             return
 
         cls._setup_fields()
